# Import library modules
import poser

# You must have an EZPlugin class with the requisite attributes
class EZPlugin(object):
	def __init__(self, manager):
		self.pm = manager
		self.name = 'JustMaps'
		self.internalname = 'org.snarlygribbly.justmaps'
		self.description = 'reduces the shader to just the imagemap nodes'

	# REQUIRED: The Apply method will be called by EZMat to use your plugin.
	def Apply(self, mats):
		# mats = a list of Poser Material objects

		# Process each material in turn
		for material in mats:

			# Get the EZMat helper for the material
			mat = self.pm.GetMatHelper(material)

			# Implement your shader
			self.MakeMat(mat, self.pm.GetParameter)
			mat.UpdatePreview()

	# REQUIRED: Returns the plugin description
	def Description(self):
		return self.description

	# REQUIRED: Returns the plugin name
	def PluginName(self):
		return self.name

	# An arbitrary method used to implement your shader. Can be generated from generator.py
	def MakeMat(self, mat, p):

		# Disconect all nodes from PoserSurface
		for i in mat.Root().Inputs():
			i.Disconnect()

		# Delete all nodes that are not maps
		for n in mat.AllNodes():
			if n.Type() != poser.kNodeTypeCodeIMAGEMAP:
				try:
					n.Delete()
				except:
					pass

		# Link maps to Inputs
		xref = {
			"color" : "Diffuse_Color",
			"alt_color" : "AlternateDiffuse",
			"specular" : "Highlight_Value",
			"alt_specular" : "AlternateSpecular",
			"bump" : "Bump",
			"displacement" : "Displacement",
			"transparency" : "Transparency_Max",
			"reflection" : "Reflection_Color",
			"specular_color" : "Highlight_Color"
			}

		# Connect maps to PoserSurface
		for imagemapnode, input in xref.items():

			map = mat.GetMap(imagemapnode)
			if map:
				mat.ConnectToPS(map, input)



